pub enum NotationLossKind {
Clef,
PartName,
PitchSpelling,
DefaultedTempo,
DefaultedTimeSignature,
Velocity,
Channel,
}Expand description
Machine-readable kind of information not carried by canonical Score.
Variants
Clef
Clef/layout metadata has no effect on canonical score semantics.
PartName
A single-part display name is not carried by a melody score body.
PitchSpelling
Enharmonic source spelling is not carried by canonical chromatic pitch.
DefaultedTempo
A missing tempo was replaced by the profile default.
DefaultedTimeSignature
A missing meter was replaced by the profile default.
Velocity
A note velocity cannot be represented by the bounded MusicXML subset.
Channel
A MIDI channel cannot be represented by the bounded MusicXML subset.