pub fn export_musicxml_partwise(score: &Score) -> Result<String, NotationError>Expand description
Exports with deterministic profile identifiers and discards sidecar evidence.
pub fn export_musicxml_partwise(score: &Score) -> Result<String, NotationError>Exports with deterministic profile identifiers and discards sidecar evidence.