pub fn import_musicxml_partwise(
source: &[u8],
limits: MusicXmlLimits,
) -> Result<Score, NotationError>Expand description
Imports the bounded profile and discards exchange sidecar evidence.
pub fn import_musicxml_partwise(
source: &[u8],
limits: MusicXmlLimits,
) -> Result<Score, NotationError>Imports the bounded profile and discards exchange sidecar evidence.